# lyrics_hunter
Lyrics Hunter is a python library to scrape lyrics from websites. It is a web scraping library designed to extract song lyrics from websites. The library currently only supports scraping from lyrics.com but in near future, it will support more websites.
